Rackspace Auth Plugin for OpenStack Neutron Clients
===================================================

This is a plugin for OpenStack Clients which provides client support for
Rackspace authentication extensions to OpenStack Neutron.
